@@ -256,7 +256,7 @@ class Client(Methods):
         else:
             self.storage = FileStorage(self.name, self.workdir)
 
-        if self.end_client:
+        if end_client:
             if self.bot_token:
                 pass
             else:
